import pathlib

from setuptools import setup
from setuptools.extension import Extension
from Cython.Build import cythonize


_ROOT = pathlib.Path(__file__).parent


with open(str(_ROOT / "uvloop" / "_version.py")) as f:
    for line in f:
        if line.startswith("__version__ ="):
            _, _, version = line.partition("=")
            VERSION = version.strip(" \n'\"")
            break
    else:
        raise RuntimeError("unable to read the version from uvloop/_version.py")


setup(
    version=VERSION,
    packages=["uvloop", "uvloop.includes", "uvloop.handles"],
    ext_modules=cythonize(
        Extension("uvloop.loop", ["uvloop/loop.pyx"], extra_link_args=["-luv"]),
    ),
    setup_requires="Cython(>=0.29.36,<0.30.0)",
)
